<?php
namespace Plugin\View;

use Plugin\Exception\Error;
use App\Config\Settings;

class ArrayObjectAccess implements \ArrayAccess {
	
	private $container = array();
	private $services;

	public function __construct() {
		$apps = Settings::getAppsInfo();
		$allServices = array();
		foreach($apps as $name => $ressources){
			foreach($ressources as $res){
				$path = ROOT_DIR."src/$name/$res/Config/service.php";
				if (file_exists($path)){
					include $path;
					$allServices = array_merge($allServices,$services);
				}
			}
		}
		$this->services = $allServices;
		
		foreach($allServices as $name => $service) {
			$obj = $this->instantiate($service["class"]);
			$this->container[$name] = $obj;
		}
		
	}

	public function offsetSet($offset, $value) {
		if (is_null($offset)) {
			$this->container[] = $value;
		} else {
			$this->container[$offset] = $value;
		}
	}

	public function offsetExists($offset) {
		return isset($this->container[$offset]);
	}

	public function offsetUnset($offset) {
		unset($this->container[$offset]);
	}

	public function offsetGet($offset) {
		if (!isset($this->container[$offset])){
			Error::throw500("The Helper '$offset' is not defined. Check your services config");
		}
		return $this->container[$offset];
	}
	
	private function instantiate($string){
		list($app,$section,$type,$name) = explode(":", $string);
		$className = "src\\$app\\$section\\$type\\$name";
		return new $className();
	}
	
}